@@ -1,5 +1,5 @@
-from colorama import Fore, Style, init as colorama_init
-
+from colorama import Fore, Style
+from colorama import init as colorama_init
 
 colorama_init()
 
@@ -22,8 +22,14 @@ class Color(object):
         return self.color_dict.get(name, "")
 
     def __getitem__(self, name):
+        """
+        color[<color_code>] returns a function that colors
+        given text to that color
+        """
+
         def apply_color(content):
             return self.get(name) + content + self.get("neutral")
+
         return apply_color
 
 
